@@ -1,5 +1,5 @@
 package Crypt::GeneratePassword;
-$Crypt::GeneratePassword::VERSION = '0.04';
+$Crypt::GeneratePassword::VERSION = '0.05';
 # ABSTRACT: generate secure random pronounceable passwords
 
 use 5.006;
@@ -55,14 +55,13 @@ our @EXPORT_OK   = qw(word word3 analyze analyze3 chars generate_language load_l
 our %EXPORT_TAGS = ( 'all' => [ @Crypt::GeneratePassword::EXPORT_OK ] );
 
 my $default_language = 'en';
-use vars qw(%languages);
-%languages = ();
+our %languages = ();
 
 =head2 chars
 
   $word = chars($minlen, $maxlen [, $set [, $characters, $maxcount ] ... ] );
 
-Generatess a completely random word between $minlen and $maxlen in length.
+Generates a completely random word between $minlen and $maxlen in length.
 If $set is given, it must be an array ref of characters to use. You can
 restrict occurrence of some characters by providing ($characters, $maxcount)
 pairs, as many as you like. $characters must be a string consisting of those
@@ -125,7 +124,7 @@ values are around 0.05 for trigrams (word3) and 0.001 for quadgrams (word).
 
 =cut
 
-use vars qw($total);
+our $total;
 
 sub word($$;$$$$$)
 {
@@ -370,7 +369,7 @@ sub generate_language($@) {
   load_language($language_description, $name [, $default]);
 
 Loads a language description which is then available in words().
-$language_desription is a string returned by generate_language,
+$language_description is a string returned by generate_language,
 $name is a name of your choice which is used to select this
 language as the fifth parameter of words(). You should use the
 well-known ISO two letter language codes if possible, for best
@@ -392,16 +391,21 @@ sub load_language($$;$) {
 
   $number = random_number($limit);
 
-Returns a random integer between 0 (inclusive) and $limit (exclusive).
+Returns a random integer between 0 (inclusive) and C<$limit> (exclusive).
 Change this to a function of your choice by doing something like this:
 
+    sub my_rng ($) {
+        ...
+    }
+
     {
-      local $^W; # squelch sub redef warning.
+      # suppress warning about function being redefined
+      no warnings 'redefine';
       *Crypt::GeneratePassword::random_number = \&my_rng;
     }
 
-The default implementation uses perl's rand(), which might not be
-appropriate for some sites.
+The default implementation uses perl's rand(),
+which might not be appropriate for some sites.
 
 =cut
 
@@ -417,8 +421,12 @@ Filters undesirable words. Returns false if the $word is allowed
 in language $lang, false otherwise. Change this to a function of
 your choice by doing something like this:
 
+    sub my_filter ($$) {
+        ...
+    }
+
     {
-      local $^W; # squelch sub redef warning.
+      no warnings 'redefine';
       *Crypt::GeneratePassword::restrict = \&my_filter;
     }
 
@@ -439,7 +447,7 @@ L<Crypt::RandPasswd>
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Crypt-GeneratePassword>
+L<https://github.com/neilb/Crypt-GeneratePassword>
 
 =head1 AUTHOR
 
@@ -447,6 +455,8 @@ Copyright 2002 by Jörg Walter <jwalt@cpan.org>,
 inspired by ideas from Tom Van Vleck and Morris
 Gasser/FIPS-181.
 
+Now maintained by Neil Bowers E<lt>neilb@cpan.orgE<gt>
+
 =head1 COPYRIGHT
 
 This perl module is free software; it may be redistributed and/or modified
@@ -454,3 +464,5 @@ under the same terms as Perl itself.
 
 
 =cut
+
+1;
